@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
+"""Rule dataclass"""
 
-
-from dataclasses import dataclass
 from typing import List
+from dataclasses import dataclass
 
-from .condition import Condition
 from .bucket import Bucket
+from .condition import Condition
 
 
 @dataclass
 class Rule:
+    """Split Definition's Rule model"""
     buckets: List[Bucket]
     condition: Condition
