@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+"""Split dataclass"""
 
 
 from dataclasses import dataclass
@@ -10,6 +11,7 @@ from .tag import Tag
 
 @dataclass
 class Split:
+    """Split model"""
     name: str
     description: str = ''
     trafficType: Optional[TrafficType] = None
