@@ -1,6 +1,10 @@
+# -*- coding: utf-8 -*-
+
+
 from dataclasses import dataclass
 from typing import List
-from splitiorequests.models.splits.split import Split
+
+from .split import Split
 
 
 @dataclass
