@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
-
+"""Tag dataclass"""
 
 from dataclasses import dataclass
 
 
 @dataclass
 class Tag:
+    """Tag model"""
     name: str
