@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+"""Traffic Type dataclass"""
 
 
 from dataclasses import dataclass
@@ -6,5 +7,6 @@ from dataclasses import dataclass
 
 @dataclass
 class TrafficType:
+    """Traffic Type model"""
     name: str
     traffic_id: str
