@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Environment Schema"""
 
 from marshmallow import Schema, fields, post_dump, post_load
 
@@ -7,6 +7,10 @@ from splitiorequests.models.environments.environment import Environment
 
 
 class EnvironmentSchema(Schema):
+    """Environment schema class
+
+    Raises exception when unknown field is detected
+    """
     class Meta:
         ordered = True
 
@@ -28,10 +32,12 @@ class EnvironmentSchema(Schema):
 
     @post_load
     def load_environment(self, data, **kwargs):
+        """Generates and returns Environment object"""
         return Environment(**data)
 
     @post_dump
     def return_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary and removes empty fields"""
         new_data = data.copy()
         for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
