@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Default Rule Schema with exclude"""
 
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
 
@@ -7,6 +7,10 @@ from splitiorequests.models.splits.default_rule import DefaultRule
 
 
 class DefaultRuleSchemaExclude(Schema):
+    """DefaultRule schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         unknown = EXCLUDE
         ordered = True
@@ -16,8 +20,10 @@ class DefaultRuleSchemaExclude(Schema):
 
     @post_load
     def load_default_rule(self, data, **kwargs):
+        """Generates and returns DefaultRule object"""
         return DefaultRule(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
