@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definitions Schema"""
 
 from marshmallow import Schema, fields, post_load, post_dump
 
@@ -8,6 +8,10 @@ from splitiorequests.models.splits.split_definitions import SplitDefinitions
 
 
 class SplitDefinitionsSchema(Schema):
+    """Split Definitions schema class
+
+    Raises exception when unknown field is detected
+    """
     class Meta:
         ordered = True
 
@@ -18,8 +22,10 @@ class SplitDefinitionsSchema(Schema):
 
     @post_load
     def load_split_definitions(self, data, **kwargs):
+        """Generates and returns SplitDefinitions object"""
         return SplitDefinitions(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
