@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definitions Schema with exclude"""
 
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
 
@@ -8,6 +8,10 @@ from splitiorequests.models.splits.split_definitions import SplitDefinitions
 
 
 class SplitDefinitionsSchemaExclude(Schema):
+    """SplitDefinitions schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         unknown = EXCLUDE
         ordered = True
@@ -19,8 +23,10 @@ class SplitDefinitionsSchemaExclude(Schema):
 
     @post_load
     def load_split_definitions(self, data, **kwargs):
+        """Generates and returns SplitDefinitions object"""
         return SplitDefinitions(**data)
 
     @post_dump
     def clean_empty(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
