@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Schema"""
 
 from marshmallow import Schema, fields, post_dump, post_load
 
@@ -9,6 +9,10 @@ from splitiorequests.models.splits.split import Split
 
 
 class SplitSchema(Schema):
+    """Split schema class
+
+    Raises exception when unknown field is detected
+    """
     class Meta:
         ordered = True
 
@@ -20,10 +24,15 @@ class SplitSchema(Schema):
 
     @post_load
     def load_split(self, data, **kwargs):
+        """Generates and returns Split object"""
         return Split(**data)
 
     @post_dump
     def clean_empty(self, data, **kwargs):
+        """Converts Schema object into dictionary and removes empty fields
+
+        Removes all empty keys except tags and description
+        """
         new_data = data.copy()
         for field_key in (key for key in data if key != 'tags' and key != 'description' and data[key] is None):
             del new_data[field_key]
