@@ -1,5 +1,9 @@
+# -*- coding: utf-8 -*-
+
+
 from marshmallow import Schema, fields, post_load, post_dump
-from splitiorequests.schemas.splits.split_schema import SplitSchema
+
+from .split_schema import SplitSchema
 from splitiorequests.models.splits.splits import Splits
 
 
