@@ -1,6 +1,9 @@
 from .splits import (load_split, dump_split, load_splits, dump_splits, load_split_definition,
                      dump_split_definition, load_split_definitions, dump_split_definitions)
 from .environments import load_environment, dump_environment, load_environments, dump_environments
+from .workspaces import load_workspaces, dump_workspaces
+from .traffic_types import load_traffic_types, dump_traffic_types
+from .tags import load_tags, dump_tags
 
 __all__ = [
     'load_split',
@@ -15,4 +18,10 @@ __all__ = [
     'dump_environment',
     'load_environments',
     'dump_environments',
+    'load_workspaces',
+    'dump_workspaces',
+    'load_traffic_types',
+    'dump_traffic_types',
+    'load_tags',
+    'dump_tags',
 ]
